---
name: Bug report
about: Report a bug to help us improve the trisicell
title: ''
labels: bug
assignees: ''
---

### Description
<!-- Give a clear and concise description of the bug: -->
...

### Minimal reproducible example
<!-- Put an example code with which we can reproduce the bug: -->
```python
...
```
### Traceback
<!-- If applicable, replace `...` with an error traceback below: -->
<details>
```pytb
...
```
</details>

### Version
<!-- Output of trisicell.__version__ -->
...
